@@ -17,6 +17,11 @@ $curcontent =& $curnode->GetContent();
 $modified_date = $curcontent->GetModifiedDate();
 $modified_date = date('Y-m-d\TH:i:sP',$modified_date);
 $currentYear = date('Y');
+if ($this->GetPreference('meta_block_title','') != '') {
+    $meta_block = str_replace(' ','_',$this->GetPreference('meta_block_title',''));
+} else {
+    $meta_block_title = '';
+}
 if ($this->GetPreference('block_title','') != '') {
     $description_block = str_replace(' ','_',$this->GetPreference('block_title',''));
 } else {
@@ -76,8 +81,10 @@ if ($keywords != '') {
 
 $keywordsskip = preg_split("/[\s,]+/", $this->GetPreference('keyskip_title','i, me, my, myself, we, our, ours, ourselves, you, your, yours, yourself, yourselves, he, him, his, himself, she, her, hers, herself, it, its, itself, they, them, their, theirs, themselves, what, which, who, whom, this, that, these, those, am, is, are, was, were, be, been, being, have, has, had, having, do, does, did, doing, a, an, the, and, but, if, or, because, as, until, while, of, at, by, for, with, about, against, between, into, through, during, before, after, above, below, to, from, up, down, in, out, on, off, over, under, again, further, then, once, here, there, when, where, why, how, all, any, both, each, few, more, most, other, some, such, no, nor, not, only, own, same, so, than, too, very'));
 
-$worddiff = array_diff($words, $skipwords); //Strip any STOP words out of the keywords
-$worddiff = array_diff($worddiff, $defwords); //Strip any Default keywords out to prevent duplication
+if (is_array($worddiff)) {
+    $worddiff = array_diff($words, $skipwords); //Strip any STOP words out of the keywords
+    $worddiff = array_diff($worddiff, $defwords); //Strip any Default keywords out to prevent duplication
+}
 
 if (is_array($worddiff)) {
     $count = array_count_values($worddiff);
@@ -161,6 +168,7 @@ if ($this->GetPreference('allow_add',1) == 1) {
    $this->smarty->assign('delimiter_title', $this->GetPreference('delimiter_title','::'));
    $this->smarty->assign('meta_title', $this->GetPreference('meta_title',''));
    $this->smarty->assign('descriptions_title', $this->GetPreference('descriptions_title',''));
+   $this->smarty->assign('descriptions_title', $this->GetPreference('descriptions_title',''));
    $this->smarty->assign('keywords_title', $skipwords);
    $this->smarty->assign('keywords_default', $this->GetPreference('key_default',''));
    $this->smarty->assign('keyskip_title', $this->GetPreference('keyskip_title','i, me, my, myself, we, our, ours, ourselves, you, your, yours, yourself, yourselves, he, him, his, himself, she, her, hers, herself, it, its, itself, they, them, their, theirs, themselves, what, which, who, whom, this, that, these, those, am, is, are, was, were, be, been, being, have, has, had, having, do, does, did, doing, a, an, the, and, but, if, or, because, as, until, while, of, at, by, for, with, about, against, between, into, through, during, before, after, above, below, to, from, up, down, in, out, on, off, over, under, again, further, then, once, here, there, when, where, why, how, all, any, both, each, few, more, most, other, some, such, no, nor, not, only, own, same, so, than, too, very'));
@@ -181,6 +189,10 @@ if ($this->GetPreference('allow_add',1) == 1) {
    $this->smarty->assign('analyticstype_title', $this->GetPreference('analyticstype_title','-1'));
    $this->smarty->assign('propertyid_title', $this->GetPreference('propertyid_title',''));
    $this->smarty->assign('webmasterid_title', $this->GetPreference('webmasterid_title',''));
+   $this->smarty->assign('pretty_title', $this->GetPreference('pretty_title','0'));
+   $this->smarty->assign('post_title', $this->GetPreference('post_title','0'));
+   $this->smarty->assign('query_title', $this->GetPreference('query_title',''));
+   $this->smarty->assign('results_title', $this->GetPreference('results_title',''));
    $this->smarty->assign('bingid_title', $this->GetPreference('bingid_title',''));
    $this->smarty->assign('opendoctype_title', $this->GetPreference('opendoctype_title','0'));
    $this->smarty->assign('doctype_title', $this->GetPreference('doctype_title','-1'));
@@ -199,6 +211,7 @@ if ($this->GetPreference('allow_add',1) == 1) {
    $this->smarty->assign('compatible_title', $this->GetPreference('compatible_title','0'));
    $this->smarty->assign('compatibleie_title', $this->GetPreference('compatibleie_title','-1'));
    $this->smarty->assign('compatiblechrome_title', $this->GetPreference('compatiblechrome_title','-1'));
+   $this->smarty->assign('meta_block', $curcontent->GetPropertyValue($meta_block));
    $this->smarty->assign('description_block', $curcontent->GetPropertyValue($description_block));
    $this->smarty->assign('page_description', $desc);
 }
