@@ -21,6 +21,7 @@ $lang['meta_title_legend'] = 'Meta tags';
 $lang['metaoptions_title_legend'] = 'Meta content';
 $lang['keywords_title_legend'] = 'Keyword settings';
 $lang['analytics_title_legend'] = 'Google Analytics settings';
+$lang['search_title_legend'] = 'Google Analytics Search settings (All fields are required for this feature to work)';
 $lang['bing_title_legend'] = 'Bing webmaster settings';
 $lang['tab_mod_general'] = 'General settings';
 $lang['tab_mod_html'] = 'HTML tag settings';
@@ -34,6 +35,8 @@ $lang['page_title'] = 'Page title';
 $lang['page_title_help'] = 'This will get appended to your page and site name';
 $lang['delimiter_title'] = 'Page title delimiter';
 $lang['delimiter_title_help'] = 'This is the symbol used to seperate your title text';
+$lang['meta_block_title'] = 'Name of metadata content block';
+$lang['meta_block_title_help'] = 'This should be the name given to your metadata content block, check module help for more info';
 $lang['block_title'] = 'Name of page description content block';
 $lang['block_title_help'] = 'This should be the name given to your page description content block, check module help for more info';
 $lang['length_title'] = 'Number of words to appear in auto description';
@@ -117,6 +120,12 @@ $lang['analytics_sub'] = 'One domain with multiple subdomains';
 $lang['analytics_multiple'] = 'Multiple top-level domains';
 $lang['propertyid_title'] = 'Web Property ID';
 $lang['webmasterid_title'] = 'Webmaster meta verification key';
+$lang['pretty_title'] = 'Are pretty URLs enabled?';
+$lang['post_title'] = 'Search type POST being used?';
+$lang['query_title'] = 'Query parameter';
+$lang['query_help'] = 'This must be the same as the one entered in your Analytics account settings';
+$lang['results_title'] = 'Results page alias';
+$lang['results_help'] = 'Page alias of your search results page';
 $lang['bingid_title'] = 'Bing verification ID';
 $lang['changelog'] = '<ul>
 <li>Version 1.0. 10 December 2011. Initial Release.</li>
@@ -130,7 +139,10 @@ $lang['changelog'] = '<ul>
 <li>Version 1.6.2. 21 December 2011. Added more HTML tag controls.</li>
 <li>Version 1.6.3. 21 December 2011. Added X-UA-Compatability Meta tag and controls.</li>
 <li>Version 1.6.4. 25 January 2012. Bug fix #7513 as suggested by Stephen Owens.</li>
-<li>Version 1.6.5. 27 January 2012. Removed error if no text appears in the page content area.</li><</ul>';
+<li>Version 1.6.5. 27 January 2012. Removed error if no text appears in the page content area.</li>
+<li>Version 1.6.6. 31 January 2012. Added Analytics search options.</li>
+<li>Version 1.6.7. 22 February 2012. Bug fixes and addition of Metadata content block to enable page specific metadata.</li>
+<li>Version 1.6.8. 24 February 2012. Minor bug fix.</li></ul>';
 $lang['help'] = '<h3>What Does This Do?</h3>
 <p>This module adds the ability to include additional Meta data, Analytics tracking code and other useful SEO information. It can also be used to generate Doctype and Head tags, replacing the entire head of your document.</p>
 <h3>How Do I Use It</h3>
@@ -139,6 +151,8 @@ $lang['help'] = '<h3>What Does This Do?</h3>
 <p>Firstly you need to remove the standard &#123;metadata} call, this is not compatible with Meta Max and may cause problems. You may also need to remove your <DOCTYPE>, opening <html> tag and <head> tags depending on which parameters you have enabled.</p>
 <p>Just add &#123;MetaMax} to the top or head of each template.</p>
 <p>If you are using the auto description option you will need to add &#123;capture}&#123;content block=\'Page Description\' oneline=\'true\' wysiwyg=\'false\'}&#123;/capture} to your templates and reference this content blocks name in the \'page description content block\' input field, which in this example is Page Description.</p>
+<p>If you want page specific metadata simply add &#123;capture}&#123;content block=\'Metadata\' wysiwyg=\'false\'}&#123;/capture} to your templates and reference this content blocks namie in the \'metadata content block\' input field, which in this example is Metadata.</p>
+<p>The Analytics search options are only required if you are using pretty URL\'s in conjunction with the search module\'s POST method otherwise simply adding the default cntnt01searchinput into your Analytics setup will track site search queries.</p>
 <h3>Support</h3>
 <p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
 <ul>
